<?php
/**
* Functions file.
*
* @package basically-bootstrap-4
*/

// Layout

if ( ! isset( $content_width ) ) {
	$content_width = 1140;
}

$header = get_theme_mod( 'basically_bootstrap_4_header_width' );
if ($header == '') {
  $header == 'page';
}
define("HEADER", $header);

$blog_sidebar = get_theme_mod( 'basically_bootstrap_4_blog_sidebar' );
if ($blog_sidebar == '') {
  $blog_sidebar = 'left';
}
define("BLOG_SIDEBAR", $blog_sidebar);

$footer_width = get_theme_mod( 'basically_bootstrap_4_footer_width' );
if ($footer_width == '') {
  $footer_width == 'page';
}
define("FOOTER", $footer_width);

$footer_columns = get_theme_mod( 'basically_bootstrap_4_footer_number_columns' );
if ($footer_columns == '') {
	$footer_columns = 4;
}
define("FOOTER_COLUMNS", $footer_columns);

// Customizer additions.
require_once get_template_directory() . '/inc/customizer.php';

// Custom navigation walker
require_once get_template_directory() . ('/inc/wp-bootstrap-navwalker.php');

// Custom pagination
require_once get_template_directory() . '/inc/basically-bootstrap-4-pagination.php';

function basically_bootstrap_4_enqueue_style() {
  wp_enqueue_style( 'bootstrap-css', get_template_directory_uri() . '/assets/css/bootstrap.min.css' );
  if ( is_child_theme() ) {
    wp_enqueue_style( 'parent-stylesheet', trailingslashit( get_template_directory_uri() ) . 'style.css', false );
  }
  wp_enqueue_style( 'theme-stylesheet', get_stylesheet_uri(), false );
}
add_action( 'wp_enqueue_scripts', 'basically_bootstrap_4_enqueue_style' );

function basically_bootstrap_4_styles_method() {
  wp_enqueue_style(
    'custom-style',
    get_template_directory_uri() . '/assets/css/custom.css'
  );
  $color = get_theme_mod( 'basically_bootstrap_4_background_color' );
  if ($color == '') {
    $color = 'transparent';
  }
  $header_color = get_theme_mod( 'basically_bootstrap_4_header_background_color' );
  if ($header_color == '') {
    $header_color = 'transparent';
  }
  $header_image = get_theme_mod( 'basically_bootstrap_4_header_background_image' );
  $footer_color = get_theme_mod( 'basically_bootstrap_4_footer_background_color' );
  if ($footer_color == '') {
    $footer_color = 'transparent';
  }
  $footer_image = get_theme_mod( 'basically_bootstrap_4_footer_background_image' );
  $custom_css = "
  body {
    background-color: {$color};
  }
  .header-background {
    background-color: {$header_color};
  }
  .footer-background {
    background-color: {$footer_color};
  }";
  if ($header_image != '') {
    $custom_css .= "
    .header-background {
      background-image: url('{$header_image}');
    }
    ";
  }
  if ($footer_image != '') {
    $custom_css .= "
    .footer-background {
      background-image: url('{$footer_image}');
    }
    ";
  }
  wp_add_inline_style( 'custom-style', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'basically_bootstrap_4_styles_method' );

function basically_bootstrap_4_enqueue_scripts() {
  global $wp_scripts;
  wp_enqueue_script( 'tether', get_template_directory_uri() . '/assets/js/tether.min.js', array(), null, false );
  wp_enqueue_script( 'bootstrap_js', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array('jquery'), null, false );
	if (is_singular() && get_option('thread_comments')) {
	  wp_enqueue_script('comment-reply');
	}
}
add_action( 'wp_enqueue_scripts', 'basically_bootstrap_4_enqueue_scripts');

// Theme support
add_theme_support( 'title-tag' );
add_theme_support( 'post-thumbnails', array( 'post' ) );
add_theme_support( 'menus' );
add_theme_support( 'html5', array( 'comment-list' ) );
add_theme_support( 'custom-logo', array(
  'width'       => 150,
  'height'      => 150,
  'flex-width'  => true,
) );
add_theme_support( 'automatic-feed-links' );

function basically_bootstrap_4_remove_css_section( $wp_customize ) {
  $wp_customize->remove_section( 'custom_css' );
}
add_action( 'customize_register', 'basically_bootstrap_4_remove_css_section', 15 );

// Register Menu Area
function basically_bootstrap_4_register_menu() {
  register_nav_menu('header-menu',__( 'Header Menu', 'basically-bootstrap-4' ));
}
add_action( 'init', 'basically_bootstrap_4_register_menu' );

// Register widget area.
function basically_bootstrap_4_widgets_init() {
  register_sidebar( array(
    'name'          => __( 'Sidebar right', 'basically-bootstrap-4' ),
    'id'            => 'basically-bootstrap-4-sidebar-right',
    'description'   => __('Shown on the rigth side of pages containing right sidebar.', 'basically-bootstrap-4'),
    'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<h3 class="widget-title">',
    'after_title'   => '</h3>',
    )
  );
  register_sidebar( array(
    'name'          => __( 'Sidebar left', 'basically-bootstrap-4' ),
    'id'            => 'basically-bootstrap-4-sidebar-left',
    'description'   => __('Shown on the left side of pages containing left sidebar.', 'basically-bootstrap-4'),
    'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<h3 class="widget-title">',
    'after_title'   => '</h3>',
    )
  );
  register_sidebar( array(
    'name'          => __( 'Sidebar blog', 'basically-bootstrap-4' ),
    'id'            => 'basically-bootstrap-4-sidebar-blog',
    'description'   => __('Sidebar shown on blog pages (either left or right, choose under Customize).', 'basically-bootstrap-4'),
    'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<h3 class="widget-title">',
    'after_title'   => '</h3>',
    )
  );
  register_sidebar( array(
    'name'          => __( 'Footer Area Top', 'basically-bootstrap-4' ),
    'id'            => 'basically-bootstrap-4-footer-top',
    'description'   => __('Shown on the top of the footer.', 'basically-bootstrap-4'),
    'before_widget' => '<div id="footer-area-top-%1$s" class="col-md-12">',
    'after_widget'  => '</div>',
    'before_title'  => '<h3 class="widget-title">',
    'after_title'   => '</h3>',
    )
  );

	$description_3 = '';
	$description_4 = '';
	switch(FOOTER_COLUMNS) {
		case 2:
			$class = 'col-md-6';
			$description_3 = __('Not used (you have chosen only to use two columns under Customize)', 'basically-bootstrap-4');
			$description_4 = __('Not used (you have chosen only to use two columns under Customize)', 'basically-bootstrap-4');
			break;
		case 3:
			$class = 'col-md-4';
			$description_3 = __('Shown in the third area in the footer.', 'basically-bootstrap-4');
			$description_4 = __('Not used (you have chosen only to use three columns under Customize)', 'basically-bootstrap-4');
			break;
		case 4:
			$description_3 = __('Shown in the third area in the footer.', 'basically-bootstrap-4');
			$description_4 = __('Shown in the fourth area in the footer.', 'basically-bootstrap-4');
			$class = 'col-md-3 col-sm-6';
			break;
		default:
			$description = '';
			$class = 'col-md-3 col-sm-6';
			break;
	}

  register_sidebar( array(
    'name'          => __( 'Footer Area 1', 'basically-bootstrap-4' ),
    'id'            => 'basically-bootstrap-4-footer-1',
    'description'   => __('Shown in the first area in the footer.', 'basically-bootstrap-4'),
    'before_widget' => '<div id="footer-area-1-%1$s" class="' . $class . '">',
    'after_widget'  => '</div>',
    'before_title'  => '<h3 class="widget-title">',
    'after_title'   => '</h3>',
    )
  );
  register_sidebar( array(
    'name'          => __( 'Footer Area 2', 'basically-bootstrap-4' ),
    'id'            => 'basically-bootstrap-4-footer-2',
    'description'   => __('Shown in the second area in the footer.', 'basically-bootstrap-4'),
    'before_widget' => '<div id="footer-area-2-%1$s" class="' . $class . '">',
    'after_widget'  => '</div>',
    'before_title'  => '<h3 class="widget-title">',
    'after_title'   => '</h3>',
    )
  );
  register_sidebar( array(
    'name'          => __( 'Footer Area 3', 'basically-bootstrap-4' ),
    'id'            => 'basically-bootstrap-4-footer-3',
    'description'   => $description_3,
    'before_widget' => '<div id="footer-area-3-%1$s" class="' . $class . '">',
    'after_widget'  => '</div>',
    'before_title'  => '<h3 class="widget-title">',
    'after_title'   => '</h3>',
    )
  );
  register_sidebar( array(
    'name'          => __( 'Footer Area 4', 'basically-bootstrap-4' ),
    'id'            => 'basically-bootstrap-4-footer-4',
    'description'   => $description_4,
    'before_widget' => '<div id="footer-area-1-%1$s" class="' . $class . '">',
    'after_widget'  => '</div>',
    'before_title'  => '<h3 class="widget-title">',
    'after_title'   => '</h3>',
    )
  );
  register_sidebar( array(
    'name'          => __( 'Footer Area Bottom', 'basically-bootstrap-4' ),
    'id'            => 'basically-bootstrap-4-footer-bottom',
    'description'   => __('Shown on the bottom of the footer.', 'basically-bootstrap-4'),
    'before_widget' => '<div id="footer-area-bottom-%1$s" class="col-md-12">',
    'after_widget'  => '</div>',
    'before_title'  => '<h3 class="widget-title">',
    'after_title'   => '</h3>',
    )
  );
  register_sidebar( array(
    'name'          => __( 'Page not found', 'basically-bootstrap-4' ),
    'id'            => 'basically-bootstrap-4-404',
    'description'   => __('Widgets shown on the page not found page (404)', 'basically-bootstrap-4'),
    'before_widget' => '<div id="404-%1$s" class="page-not-found-widget">',
    'after_widget'  => '</div>',
    'before_title'  => '<h3 class="widget-title">',
    'after_title'   => '</h3>',
    )
  );
}
add_action( 'widgets_init', 'basically_bootstrap_4_widgets_init' );

function basically_bootstrap_4_add_bootstrap_classes_on_insert( $postarr ) {
  $postarr['post_content'] = str_replace('<blockquote>', '<blockquote class="blockquote">', $postarr['post_content'] );
  return $postarr;
}
add_filter('wp_insert_post_data', 'basically_bootstrap_4_add_bootstrap_classes_on_insert');

?>
